@@ -14,29 +14,6 @@ use vars qw ($VERSION);
 
 $VERSION = '0.01';
 
-=head1 SYNOPSIS
-
-   use Crypt::TEA_PP;
-   use Crypt::CBC;
-
-   my $tea = Crypt::TEA_PP->new( $key );
-   my $cbc = Crypt::CBC->new( -cipher => $tea );
-
-   my $text = 'The quick brown fox jumps over the lazy dog';
-   my $cipher_text = $cbc->encrypt( $text );
-
-   my $plain_text = $cbc->decrypt( $cipher_text );
-
-=head1 DESCRIPTION
-
-TEA is a 64-bit symmetric block cipher with a 128-bit key and a variable number of rounds (32 is recommended).
-It has a low setup time, and depends on a large number of rounds for security, rather than a complex algorithm.
-It was developed by David J. Wheeler and Roger M. Needham,
-and is described at <http://www.ftp.cl.cam.ac.uk/ftp/papers/djw-rmn/djw-rmn-tea.html>
-
-This module implements TEA encryption. It supports the Crypt::CBC interface, with the following functions.
-
-=cut
 
 my $DELTA = 0x9e3779b9;
 my $SUMATION = 0xc6ef3720;
@@ -46,29 +23,12 @@ my $ELEMENTS_IN_KEY = $KEY_SIZE / 4;
 my $BLOCK_SIZE = 8;
 my $ELEMENTS_IN_BLOCK = $BLOCK_SIZE / 4;
 
-=method keysize
-
-Returns the maximum TEA key size, 16 bytes.
-
-=cut
 
 use constant keysize => $KEY_SIZE;
 
-=method blocksize
-
-Returns the TEA block size, which is 8 bytes. This function exists so that Crypt::TEA_PP can work with Crypt::CBC.
-
-=cut
 
 use constant blocksize => $BLOCK_SIZE;
 
-=method new
-
-    my $tea =  Crypt::TEA_PP->new( $key, $rounds );
-This creates a new Crypt::TEA_PP object with the specified key.
-The optional rounds parameter specifies the number of rounds of encryption to perform, and defaults to 32.
-
-=cut
 
 sub new {
     my $class = shift;
@@ -93,12 +53,6 @@ sub new {
     bless $self, ref($class) || $class;
 }
 
-=method encrypt
-
-    $cipher_text = $tea->encrypt($plain_text);
-Encrypts blocksize() bytes of $data and returns the corresponding ciphertext.
-
-=cut
 
 sub encrypt {
     my $self = shift;
@@ -109,12 +63,6 @@ sub encrypt {
     return pack( 'L>*', @{$cipher_text_ref} );
 }
 
-=method
-
-    $plain_text = $tea->decrypt($cipher_text);
-Decrypts blocksize() bytes of $data and returns the corresponding plaintext.
-
-=cut
 
 sub decrypt {
     my $self = shift;
@@ -178,12 +126,85 @@ sub key_setup {
     return \@tea_key;
 }
 
-=head1 SEE ALSO
-
-=for :list
-* L<http://www.vader.brad.ac.uk/tea/tea.shtml>
-* L<Crypt::CBC>
-
-=cut
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Crypt::TEA_PP - Pure Perl Implementation of the Tiny Encryption Algorithm
+
+=head1 VERSION
+
+version 0.0101
+
+=head1 SYNOPSIS
+
+   use Crypt::TEA_PP;
+   use Crypt::CBC;
+
+   my $tea = Crypt::TEA_PP->new( $key );
+   my $cbc = Crypt::CBC->new( -cipher => $tea );
+
+   my $text = 'The quick brown fox jumps over the lazy dog';
+   my $cipher_text = $cbc->encrypt( $text );
+
+   my $plain_text = $cbc->decrypt( $cipher_text );
+
+=head1 DESCRIPTION
+
+TEA is a 64-bit symmetric block cipher with a 128-bit key and a variable number of rounds (32 is recommended).
+It has a low setup time, and depends on a large number of rounds for security, rather than a complex algorithm.
+It was developed by David J. Wheeler and Roger M. Needham,
+and is described at <http://www.ftp.cl.cam.ac.uk/ftp/papers/djw-rmn/djw-rmn-tea.html>
+
+This module implements TEA encryption. It supports the Crypt::CBC interface, with the following functions.
+
+=head1 METHODS
+
+=head2 keysize
+
+Returns the maximum TEA key size, 16 bytes.
+
+=head2 blocksize
+
+Returns the TEA block size, which is 8 bytes. This function exists so that Crypt::TEA_PP can work with Crypt::CBC.
+
+=head2 new
+
+    my $tea =  Crypt::TEA_PP->new( $key, $rounds );
+This creates a new Crypt::TEA_PP object with the specified key.
+The optional rounds parameter specifies the number of rounds of encryption to perform, and defaults to 32.
+
+=head2 encrypt
+
+    $cipher_text = $tea->encrypt($plain_text);
+Encrypts blocksize() bytes of $data and returns the corresponding ciphertext.
+
+=head2 decrypt
+
+    $plain_text = $tea->decrypt($cipher_text);
+Decrypts blocksize() bytes of $data and returns the corresponding plaintext.
+
+=head1 SEE ALSO
+
+=for :list * L<http://www.vader.brad.ac.uk/tea/tea.shtml>
+* L<Crypt::CBC>
+
+=head1 AUTHOR
+
+Kars Wang <jahiy@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Kars Wang.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
